@@ -7,7 +7,7 @@ def file_link_url(request, linkobject):
     """returns the access url of the of the dynamicLink object"""
     return '%s://%s%s/link/%s/%s' % (
         presettings.DYNAMIC_LINK_SCHEMA_PROTO,
-        request.META.get('HTTP_HOST'),
+        get_http_host(),
         presettings.DYNAMIC_LINK_URL,
         linkobject.link_key,
         linkobject.get_filename()
@@ -18,12 +18,19 @@ def site_link_url(request, siteobj):
     """returns a site urls form already given keys"""
     return '%s://%s%s/site/%s' % (
         presettings.DYNAMIC_LINK_SCHEMA_PROTO,
-        request.META.get('HTTP_HOST'),
+        get_http_host(),
         presettings.DYNAMIC_LINK_URL,
         siteobj.link_key
     )
 
 
+def get_http_host(request):
+    http_host = presettings.DYNAMIC_LINK_HTTP_HOST
+    if not http_host:
+        http_host = request.META.get('HTTP_HOST')
+    return http_host
+
+
 def gen_key():
     """
     function for generating random keys
